import numpy as np
import matplotlib.pyplot as plt
from qiskit import QuantumCircuit, transpile
from qiskit.providers.aer import QasmSimulator
from qiskit.visualization import plot_histogram

# Use Aer's qasm_simulator
simulator = QasmSimulator()

# Create a Quantum Circuit with 2 qbits
circuit = QuantumCircuit(2)

# Put some gates HERE:

circuit.h(0) #Hadamard gate on qbit 0
circuit.h(1)
#circuit.x(0)
#circuit.cnot(0,1) #Controlled NOT gate, qbit 0 as control bit and qbit 1 as target

# Measure
circuit.measure_all()

# Draw the circuit
print(circuit.draw())
# Uncomment for nicer output
#circuit.draw(output='mpl')
#might also need: plt.show()

# compile the circuit down to low-level QASM instructions
# supported by the backend (not needed for simple circuits)
compiled_circuit = transpile(circuit, simulator)

# Execute the circuit on the qasm simulator
job = simulator.run(compiled_circuit, shots=1000) #shots is the number of repetitions, 1000 is the default

# Grab results from the job
result = job.result()
counts=result.get_counts(compiled_circuit)

# Plot a histogram
plot_histogram(counts)
plt.show()
